M10Actions extension
- on
Methods
-
cancel(
{required String operator, required String fromAccountId, required String targetAccountId, required String contextId}) → Future< TransactionResponseDoc> -
Available on M10Sdk, provided by the M10Actions extension
Cancels a payment request. -
decline(
{required String operator, required String fromAccountId, required String targetAccountId, required String contextId}) → Future< TransactionResponseDoc> -
Available on M10Sdk, provided by the M10Actions extension
Declines a payment request. -
getChainInfo(
{required String operator}) → Future< ChainInfo> -
Available on M10Sdk, provided by the M10Actions extension
Retrieves a list of payment requests for a specific account. -
listRequests(
{required String operator, required String accountId, int minTxId = 0, int maxTxId = 0, int limit = 10}) → Future< List< PaymentRequestDoc> > -
Available on M10Sdk, provided by the M10Actions extension
Retrieves a list of payment requests for a specific account. -
request(
{required String operator, required CreateTransfer transferRequest, String? contextId}) → Future< TransactionResponseDoc> -
Available on M10Sdk, provided by the M10Actions extension
Initiates a payment request.
Constants
- requestActionName → const String